/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
import { Directive, Input, Output, ElementRef, EventEmitter } from "@angular/core";
import { Observable } from "rxjs/Observable";
import { fromEvent } from "rxjs/observable/fromEvent";
export class DraggbleDirective {
    /**
     * @param {?} elementRef
     */
    constructor(elementRef) {
        this.dragX = true;
        this.dragY = true;
        this.dragStart = new EventEmitter();
        this.dragging = new EventEmitter();
        this.dragEnd = new EventEmitter();
        this.isDragging = false;
        this._element = elementRef.nativeElement;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        let /** @type {?} */ handle = document.createElement('span');
        handle.setAttribute('class', 'drag-handle');
        this._element.appendChild(handle);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes['dragEventTarget'] && changes['dragEventTarget'].currentValue && this.dragModel.dragging) {
            this.onMousedown(changes['dragEventTarget'].currentValue);
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() { }
    /**
     * @param {?} event
     * @return {?}
     */
    onMousedown(event) {
        // 只拖拽表头内部的文字
        const /** @type {?} */ isDragElm = (/** @type {?} */ (event.target)).classList.contains('draggable');
        if (isDragElm && (this.dragX || this.dragY)) {
            event.preventDefault();
            this.isDragging = true;
            const /** @type {?} */ mouseDownPos = { x: event.clientX, y: event.clientY };
            const /** @type {?} */ mouseup = Observable.create(fromEvent(document, 'mouseup'));
            this.subscription = mouseup
                .subscribe((ev) => this.onMouseup(ev));
            const /** @type {?} */ mouseMoveSub = Observable.create(fromEvent(document, 'mousemove')).takeUntil(mouseup)
                .subscribe((ev) => this.move(ev, mouseDownPos));
            this.subscription.add(mouseMoveSub);
            this.dragStart.emit({
                event,
                element: this._element,
                model: this.dragModel
            });
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onMouseup(event) {
        if (!this.isDragging) {
            return;
        }
        this.isDragging = false;
        this._element.classList.remove('dragging');
        if (this.subscription) {
            this._destroySubscription();
            this.dragEnd.emit({
                event,
                element: this._element,
                model: this.dragModel
            });
        }
    }
    /**
     * @param {?} event
     * @param {?} mouseDownPos
     * @return {?}
     */
    move(event, mouseDownPos) {
        if (!this.isDragging) {
            return;
        }
        const /** @type {?} */ x = event.clientX - mouseDownPos.x;
        const /** @type {?} */ y = event.clientY - mouseDownPos.y;
        if (this.dragX) {
            this._element.style.left = `${x}px`;
        }
        if (this.dragY) {
            this._element.style.top = `${y}px`;
        }
        this._element.classList.add('dragging');
        this.dragging.emit({
            event,
            element: this._element,
            model: this.dragModel
        });
    }
    /**
     * @return {?}
     */
    _destroySubscription() {
        if (this.subscription) {
            this.subscription.unsubscribe();
            this.subscription = undefined;
        }
    }
}
DraggbleDirective.decorators = [
    { type: Directive, args: [{
                selector: '[buiDraggble]'
            },] },
];
/** @nocollapse */
DraggbleDirective.ctorParameters = () => [
    { type: ElementRef, },
];
DraggbleDirective.propDecorators = {
    "dragEventTarget": [{ type: Input },],
    "dragModel": [{ type: Input },],
    "dragX": [{ type: Input },],
    "dragY": [{ type: Input },],
    "dragStart": [{ type: Output },],
    "dragging": [{ type: Output },],
    "dragEnd": [{ type: Output },],
};
function DraggbleDirective_tsickle_Closure_declarations() {
    /** @type {!Array<{type: !Function, args: (undefined|!Array<?>)}>} */
    DraggbleDirective.decorators;
    /**
     * @nocollapse
     * @type {function(): !Array<(null|{type: ?, decorators: (undefined|!Array<{type: !Function, args: (undefined|!Array<?>)}>)})>}
     */
    DraggbleDirective.ctorParameters;
    /** @type {!Object<string,!Array<{type: !Function, args: (undefined|!Array<?>)}>>} */
    DraggbleDirective.propDecorators;
    /** @type {?} */
    DraggbleDirective.prototype.dragEventTarget;
    /** @type {?} */
    DraggbleDirective.prototype.dragModel;
    /** @type {?} */
    DraggbleDirective.prototype.dragX;
    /** @type {?} */
    DraggbleDirective.prototype.dragY;
    /** @type {?} */
    DraggbleDirective.prototype.dragStart;
    /** @type {?} */
    DraggbleDirective.prototype.dragging;
    /** @type {?} */
    DraggbleDirective.prototype.dragEnd;
    /** @type {?} */
    DraggbleDirective.prototype._element;
    /** @type {?} */
    DraggbleDirective.prototype.isDragging;
    /** @type {?} */
    DraggbleDirective.prototype.subscription;
}
//# sourceMappingURL=draggble.directive.js.map